<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 * 
 */

function osiris_option_name() {

	// This gets the theme name from the stylesheet
	$themename = get_option( 'stylesheet' );
	$themename = preg_replace("/\W/", "_", strtolower($themename) );

	$osiris_settings = get_option( 'osiris' );
	$osiris_settings['id'] = $themename;
	update_option( 'osiris', $osiris_settings );
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the "id" fields, make sure to use all lowercase and no spaces.
 *  
 */

function osiris_options() {
	
	// Test data
$number_array = array("1" => "One","2" => "Two","3" => "Three","4" => "Four","5" => "Five", "6" => "Six","7" => "Seven","8" => "Eight","9" => "Nine","10" => "Ten");
$numberfront_array = array("1" => "One","2" => "Two","3" => "Three","4" => "Four","5" => "Five", "6" => "Six","7" => "Seven","8" => "Eight","9" => "Nine","10" => "Ten","11" => "Eleven", "12" => "Twelve");

	// Fonts Array	
	$fonts_array = array(
	"lora"=>"Lora",
	"raleway"=>"Raleway","atomic+Age"=>"Atomic+Age","marck+Script"=>"Marck+Script",
	);
	
	// Test data
	$slider_array = array("nivo" => "Nivo Slider","noslider" => "No Slider");
	
	
	// Multicheck Defaults
	$multicheck_defaults = array("one" => "1","five" => "1");
	
	// Background Defaults
	
	$background_defaults = array('color' => '', 'image' => '', 'repeat' => 'repeat','position' => 'top center','attachment'=>'scroll');
	
	// Editor Defaults
		$wp_editor_settings = array(
		'wpautop' => true, // Default
		'textarea_rows' => 5,
		
		'tinymce' => array( 'plugins' => 'wordpress' )
	);
	// Pull all the categories into an array
	$options_categories = array();  
	$options_categories_obj = get_categories();
	foreach ($options_categories_obj as $category) {
    	$options_categories[$category->cat_ID] = $category->cat_name;
	}
	
	// Pull all the pages into an array
	$options_pages = array();  
	$options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	$options_pages[''] = 'Select a page:';
	foreach ($options_pages_obj as $page) {
    	$options_pages[$page->ID] = $page->post_title;
	}
		
	// If using image radio buttons, define a directory path
	$imagepath =  get_template_directory_uri() . '/admin/images/';
	
	
	
		
	
	
	
	$options = array();
	
	
	
	
	
	$options[] = array( "name" => __('Front Page', 'osiris'),
						"type" => "heading");
	
	
						
	$options[] = array( "name" => __('Front Page Layout', 'osiris'),
						"desc" => "Select a front page layout",
						"id" => "layout1_images",
						"std" => "layout1",
						"type" => "images",
						"options" => array(
							'layout1' => $imagepath.'layout1.png',
							
							));
							
$options[] = array( "name" => __('Custom logo image', 'osiris'),
						"desc" => __('You can upload custom image for your website logo (optional).', 'osiris'),
						"id" => "osiris_logo_image",
						"type" => "upload");	
		
		
		
						
	 $options[] = array( "name" => __('Home Page Callout section', 'osiris'),
						"id" => "osiris_welcome",
                        "desc" => __('If you leave this field empty, the callout section will not be displayed.','osiris'),
						"std" => "<h1>Welcome!</h1><h2>You need to configure your Home Page! </h2>Please visit Theme Options Page",
						"type" => "editor", 
						
						'settings' => $wp_editor_settings);
						
						
				
						
	$options[] = array( "name" => __('Enable Latest Posts', 'osiris'),
						"desc" => "Enable the posts under the blocks on homepage. You ca only use options below when this option is tick.",
						"id" => "latstpst_checkbox",
						"std" => "1",
						"type" => "checkbox");
						
	$options[] = array( "name" => __('Show Posts from a certain Category', 'osiris'),
						"desc" => "Show posts from certain category on frontpage. Select the category below.",
						"id" => "frontcat_checkbox",
						"std" => "0",
						"type" => "checkbox");
						
						
	$options[] = array( "name" => __('Front Page Posts Category', 'osiris'),
						"desc" => "Select a Category For Front Page.",
						"id" => "front_cat",
						"type" => "select",
						"class" => "mini",
						"options" => $options_categories);						
						
	
	
	$options[] = array( "name" => __('Number of Front page Posts', 'osiris'),
						"desc" => "Select the Number of Posts.",
						"id" => "frontnum_select",
						"std" => "4",
						"type" => "select",
						"class" => "mini", //mini, tiny, small
						"options" => $numberfront_array);	
	
	
						
	$options[] = array( "name" => __('Footer Content', 'osiris'),
						"desc" => "Footer Text.",
						"id" => "footer_textarea",
						"std" => "",
						"type" => "textarea"); 	
		
		
		
		
		//Color & Font
		
	$options[] = array( "name" => __('Color & Font', 'osiris'),
						"type" => "heading");
						
						
			
						
	$options[] = array( "name" => __('Select Font', 'osiris'),
						"desc" => "",
						"id" => "font_select",
						"std" => "raleway",
						"type" => "select",
						"class" => "mini",
						"options" => $fonts_array);

						
	
	
	$options[] = array( "name" => __('menu', 'osiris'),
						"desc" => "Change footer & header menu background color",
						"id" => "menu_colorpicker",
						"std" => "#474544",
						"type" => "color");
	
	$options[] = array( "name" => __('Title Color', 'osiris'),
						"desc" => "Change all element titel color",
						"id" => "title_colorpicker",
						"std" => "#20b8d6",
						"type" => "color");
						
				
											
	
						
	
			
	$options[] = array( "name" => __('Social', 'osiris'),
						"type" => "heading");						
						
						
	$options[] = array( "name" => __('Facebook', 'osiris'),
						"desc" => "Your Facebook url",
						"id" => "fbsoc_text",
						"std" => "#",
						"type" => "text");
						
	$options[] = array( "name" => __('Twitter', 'osiris'),
						"desc" => "Your Twitter url",
						"id" => "ttsoc_text",
						"std" => "#",
						"type" => "text");
						
	$options[] = array( "name" => __('Google Plus', 'osiris'),
						"desc" => "Your Google Plus url",
						"id" => "gpsoc_text",
						"std" => "#",
						"type" => "text");
						
	$options[] = array( "name" => __('Youtube', 'osiris'),
						"desc" => "Your Youtube url",
						"id" => "ytbsoc_text",
						"std" => "#",
						"type" => "text");
						
	
						
	$options[] = array( "name" => __('Pinterest', 'osiris'),
						"desc" => "Your Pinterest url",
						"id" => "pinsoc_text",
						"std" => "",
						"type" => "text");
						
	$options[] = array( "name" => __('Rss', 'osiris'),
						"desc" => "Your RSS url",
						"id" => "rsssoc_text",
						"std" => "",
						"type" => "text");
						
	//slider		
						
	$options[] = array( "name" => __('Slider', 'osiris'),
						"type" => "heading");
						
	$options[] = array( "name" => __('Select Slider', 'osiris'),
						"desc" => "",
						"id" => "slider_select",
						"std" => "nivo",
						"type" => "select",
						"class" => "mini", //mini, tiny, small
						"options" => $slider_array);
						
						
	$options[] = array( "name" => __('Slider Speed', 'osiris'),
						"desc" => "milliseconds",
						"id" => "sliderspeed_text",
						"std" => "3000",
						"class" => "mini",
						"type" => "text");	
						
$options[] = array( "name" => __('Number of Slides', 'osiris'),
						"desc" => "",
						"id" => "number_select",
						"std" => "5",
						"type" => "select",
						"class" => "mini", //mini, tiny, small
						"options" => $number_array);						
						
	$options[] = array( "name" => __('Slider Content', 'osiris'),
						"desc" => "Show Slider text",
						"id" => "sldrtxt_checkbox",
						"std" => "1",
						"type" => "checkbox");	
						
	
						
	$options[] = array( "name" => __('Nivo Slider thumbnails', 'osiris'),
						"desc" => "Enable Nivo Slider thumbnails and display arrows",
						"id" => "nivothumb_checkbox",
						"std" => "1",
						"type" => "checkbox");	

		
	$options[] = array(
		'name' => __('Using the Slider', 'osiris'),
		'desc' => __('This Slider supports upto 5 Images. To show only 3 Slides in the slider, upload only 3 images. Leave the rest Blank. For best results, upload images of size 1180x500px.', 'osiris'),
		'type' => 'info');

	$options[] = array(
		'name' => __('Slider Image 1', 'osiris'),
		'desc' => __('First Slide', 'osiris'),
		'id' => 'slide1',
		'class' => '',
		'type' => 'upload');
	
	$options[] = array(
		'desc' => __('Title', 'osiris'),
		'id' => 'slidetitle1',
		'std' => '',
		'type' => 'text');
	
	$options[] = array(
		'desc' => __('Description or Tagline', 'osiris'),
		'id' => 'slidedesc1',
		'std' => '',
		'type' => 'textarea');			
		
	$options[] = array(
		'desc' => __('Url', 'osiris'),
		'id' => 'slideurl1',
		'std' => '',
		'type' => 'text');		
	
	$options[] = array(
		'name' => __('Slider Image 2', 'osiris'),
		'desc' => __('Second Slide', 'osiris'),
		'class' => '',
		'id' => 'slide2',
		'type' => 'upload');
	
	$options[] = array(
		'desc' => __('Title', 'osiris'),
		'id' => 'slidetitle2',
		'std' => '',
		'type' => 'text');	
	
	$options[] = array(
		'desc' => __('Description or Tagline', 'osiris'),
		'id' => 'slidedesc2',
		'std' => '',
		'type' => 'textarea');		
		
	$options[] = array(
		'desc' => __('Url', 'osiris'),
		'id' => 'slideurl2',
		'std' => '',
		'type' => 'text');	
		
	$options[] = array(
		'name' => __('Slider Image 3', 'osiris'),
		'desc' => __('Third Slide', 'osiris'),
		'id' => 'slide3',
		'class' => '',
		'type' => 'upload');	
	
	$options[] = array(
		'desc' => __('Title', 'osiris'),
		'id' => 'slidetitle3',
		'std' => '',
		'type' => 'text');	
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'osiris'),
		'id' => 'slidedesc3',
		'std' => '',
		'type' => 'textarea');	
			
	$options[] = array(
		'desc' => __('Url', 'osiris'),
		'id' => 'slideurl3',
		'std' => '',
		'type' => 'text');		
	
	$options[] = array(
		'name' => __('Slider Image 4', 'osiris'),
		'desc' => __('Fourth Slide', 'osiris'),
		'id' => 'slide4',
		'class' => '',
		'type' => 'upload');	
		
	$options[] = array(
		'desc' => __('Title', 'osiris'),
		'id' => 'slidetitle4',
		'std' => '',
		'type' => 'text');
	
	$options[] = array(
		'desc' => __('Description or Tagline', 'osiris'),
		'id' => 'slidedesc4',
		'std' => '',
		'type' => 'textarea');			
		
	$options[] = array(
		'desc' => __('Url', 'osiris'),
		'id' => 'slideurl4',
		'std' => '',
		'type' => 'text');		
	
	$options[] = array(
		'name' => __('Slider Image 5', 'osiris'),
		'desc' => __('Fifth Slide', 'osiris'),
		'id' => 'slide5',
		'class' => '',
		'type' => 'upload');	
		
	$options[] = array(
		'desc' => __('Title', 'osiris'),
		'id' => 'slidetitle5',
		'std' => '',
		'type' => 'text');	
	
	$options[] = array(
		'desc' => __('Description or Tagline', 'osiris'),
		'id' => 'slidedesc5',
		'std' => '',
		'type' => 'textarea');		
		
	$options[] = array(
		'desc' => __('Url', 'osiris'),
		'id' => 'slideurl5',
		'std' => '',
		'type' => 'text');	
						
		
		
		//misceleneous				

	$options[] = array( "name" => __('Miscelleneous', 'osiris'),
						"type" => "heading");
						
	$options[] = array( "name" => __('Right Sidebar', 'osiris'),
						"desc" => "Remove Right sidebar from all the pages and make the site full width.",
						"id" => "nosidebar_checkbox",
						"std" => "0",
						"type" => "checkbox");
  					
	
						
						
	$options[] = array( "name" => __('Post Author Name', 'osiris'),
						"desc" => "Hide Post Author Name",
						"id" => "dissauth_checkbox",
						"std" => "0",
						"type" => "checkbox");
						
	$options[] = array( "name" => __('Category & Tags', 'osiris'),
						"desc" => "Hide Post Categories and Tags",
						"id" => "disscats_checkbox",
						"std" => "0",
						"type" => "checkbox");
	$options[] = array( "name" => __("below Wellcome tex Ad(728*90) & (970*90)", "osiris"),
                        "desc" => "Place here your ad code. Displayed in below Wellcome tex center,More ad spots available in PRO version !! ", 
                        "id" => "osiris_well_ad",
                        "std" => "",
                        "type" => "textarea"); 	
						
$options[] = array( "name" => __('Documentation', 'osiris'),
						"type" => "heading");
						
						
						
	
						
	
	
													
	return $options;
}